@@ -8,7 +8,7 @@ from mlbstatsapi.models.game.livedata.boxscore import BoxScore
 from .attributes import GameLeaders, GameDecisions
 
 
-@dataclass
+@dataclass(repr=False)
 class LiveData:
     """
     A class to represent this games live data.
@@ -21,10 +21,10 @@ class LiveData:
         This games linescore
     boxscore : BoxScore
         This games boxscore
-    leaders : LiveDataLeaders
+    leaders : GameLeaders
         The data leaders for this game
-    decisions : LiveDataDecisions = None
-        Decisions for this game, Ie a winner or a loosers
+    decisions : GameDecisions = None
+        Decisions for this game, Ie a winner or a loser
     """
     plays: Union[Plays, dict]
     boxscore: Union[BoxScore, dict]
@@ -39,3 +39,7 @@ class LiveData:
         self.boxscore = BoxScore(**self.boxscore)
         self.decisions = GameDecisions(**self.decisions) if self.decisions else self.decisions
         self.leaders = GameLeaders(**self.leaders)
+
+    def __repr__(self) -> str:
+        kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None and value]
+        return "{}({})".format(type(self).__name__, ", ".join(kws))
\ No newline at end of file
